@@ -1,25 +1,21 @@
 """
-Main interface for qldb service type definitions.
+Type annotations for qldb service type definitions.
+
+[Open documentation](./type_defs.md)
 
 Usage::
 
     ```python
-    from mypy_boto3_qldb.type_defs import JournalKinesisStreamDescriptionTypeDef
+    from mypy_boto3_qldb.type_defs import CancelJournalKinesisStreamResponseTypeDef
 
-    data: JournalKinesisStreamDescriptionTypeDef = {...}
+    data: CancelJournalKinesisStreamResponseTypeDef = {...}
     ```
 """
 import sys
 from datetime import datetime
 from typing import IO, Dict, List, Union
 
-from mypy_boto3_qldb.literals import (
-    ErrorCause,
-    ExportStatus,
-    LedgerState,
-    S3ObjectEncryptionType,
-    StreamStatus,
-)
+from .literals import ErrorCause, ExportStatus, LedgerState, S3ObjectEncryptionType, StreamStatus
 
 if sys.version_info >= (3, 8):
     from typing import TypedDict
@@ -28,13 +24,6 @@ else:
 
 
 __all__ = (
-    "JournalKinesisStreamDescriptionTypeDef",
-    "JournalS3ExportDescriptionTypeDef",
-    "KinesisConfigurationTypeDef",
-    "LedgerSummaryTypeDef",
-    "S3EncryptionConfigurationTypeDef",
-    "S3ExportConfigurationTypeDef",
-    "ValueHolderTypeDef",
     "CancelJournalKinesisStreamResponseTypeDef",
     "CreateLedgerResponseTypeDef",
     "DescribeJournalKinesisStreamResponseTypeDef",
@@ -44,15 +33,124 @@ __all__ = (
     "GetBlockResponseTypeDef",
     "GetDigestResponseTypeDef",
     "GetRevisionResponseTypeDef",
+    "JournalKinesisStreamDescriptionTypeDef",
+    "JournalS3ExportDescriptionTypeDef",
+    "KinesisConfigurationTypeDef",
+    "LedgerSummaryTypeDef",
     "ListJournalKinesisStreamsForLedgerResponseTypeDef",
     "ListJournalS3ExportsForLedgerResponseTypeDef",
     "ListJournalS3ExportsResponseTypeDef",
     "ListLedgersResponseTypeDef",
     "ListTagsForResourceResponseTypeDef",
+    "S3EncryptionConfigurationTypeDef",
+    "S3ExportConfigurationTypeDef",
     "StreamJournalToKinesisResponseTypeDef",
     "UpdateLedgerResponseTypeDef",
+    "ValueHolderTypeDef",
 )
 
+CancelJournalKinesisStreamResponseTypeDef = TypedDict(
+    "CancelJournalKinesisStreamResponseTypeDef",
+    {
+        "StreamId": str,
+    },
+    total=False,
+)
+
+CreateLedgerResponseTypeDef = TypedDict(
+    "CreateLedgerResponseTypeDef",
+    {
+        "Name": str,
+        "Arn": str,
+        "State": LedgerState,
+        "CreationDateTime": datetime,
+        "DeletionProtection": bool,
+    },
+    total=False,
+)
+
+DescribeJournalKinesisStreamResponseTypeDef = TypedDict(
+    "DescribeJournalKinesisStreamResponseTypeDef",
+    {
+        "Stream": "JournalKinesisStreamDescriptionTypeDef",
+    },
+    total=False,
+)
+
+DescribeJournalS3ExportResponseTypeDef = TypedDict(
+    "DescribeJournalS3ExportResponseTypeDef",
+    {
+        "ExportDescription": "JournalS3ExportDescriptionTypeDef",
+    },
+)
+
+DescribeLedgerResponseTypeDef = TypedDict(
+    "DescribeLedgerResponseTypeDef",
+    {
+        "Name": str,
+        "Arn": str,
+        "State": LedgerState,
+        "CreationDateTime": datetime,
+        "DeletionProtection": bool,
+    },
+    total=False,
+)
+
+ExportJournalToS3ResponseTypeDef = TypedDict(
+    "ExportJournalToS3ResponseTypeDef",
+    {
+        "ExportId": str,
+    },
+)
+
+_RequiredGetBlockResponseTypeDef = TypedDict(
+    "_RequiredGetBlockResponseTypeDef",
+    {
+        "Block": "ValueHolderTypeDef",
+    },
+)
+_OptionalGetBlockResponseTypeDef = TypedDict(
+    "_OptionalGetBlockResponseTypeDef",
+    {
+        "Proof": "ValueHolderTypeDef",
+    },
+    total=False,
+)
+
+
+class GetBlockResponseTypeDef(_RequiredGetBlockResponseTypeDef, _OptionalGetBlockResponseTypeDef):
+    pass
+
+
+GetDigestResponseTypeDef = TypedDict(
+    "GetDigestResponseTypeDef",
+    {
+        "Digest": Union[bytes, IO[bytes]],
+        "DigestTipAddress": "ValueHolderTypeDef",
+    },
+)
+
+_RequiredGetRevisionResponseTypeDef = TypedDict(
+    "_RequiredGetRevisionResponseTypeDef",
+    {
+        "Revision": "ValueHolderTypeDef",
+    },
+)
+_OptionalGetRevisionResponseTypeDef = TypedDict(
+    "_OptionalGetRevisionResponseTypeDef",
+    {
+        "Proof": "ValueHolderTypeDef",
+    },
+    total=False,
+)
+
+
+class GetRevisionResponseTypeDef(
+    _RequiredGetRevisionResponseTypeDef, _OptionalGetRevisionResponseTypeDef
+):
+    pass
+
+
 _RequiredJournalKinesisStreamDescriptionTypeDef = TypedDict(
     "_RequiredJournalKinesisStreamDescriptionTypeDef",
     {
@@ -98,10 +196,17 @@ JournalS3ExportDescriptionTypeDef = TypedDict(
 )
 
 _RequiredKinesisConfigurationTypeDef = TypedDict(
-    "_RequiredKinesisConfigurationTypeDef", {"StreamArn": str}
+    "_RequiredKinesisConfigurationTypeDef",
+    {
+        "StreamArn": str,
+    },
 )
 _OptionalKinesisConfigurationTypeDef = TypedDict(
-    "_OptionalKinesisConfigurationTypeDef", {"AggregationEnabled": bool}, total=False
+    "_OptionalKinesisConfigurationTypeDef",
+    {
+        "AggregationEnabled": bool,
+    },
+    total=False,
 )
 
 
@@ -113,15 +218,70 @@ class KinesisConfigurationTypeDef(
 
 LedgerSummaryTypeDef = TypedDict(
     "LedgerSummaryTypeDef",
-    {"Name": str, "State": LedgerState, "CreationDateTime": datetime},
+    {
+        "Name": str,
+        "State": LedgerState,
+        "CreationDateTime": datetime,
+    },
+    total=False,
+)
+
+ListJournalKinesisStreamsForLedgerResponseTypeDef = TypedDict(
+    "ListJournalKinesisStreamsForLedgerResponseTypeDef",
+    {
+        "Streams": List["JournalKinesisStreamDescriptionTypeDef"],
+        "NextToken": str,
+    },
+    total=False,
+)
+
+ListJournalS3ExportsForLedgerResponseTypeDef = TypedDict(
+    "ListJournalS3ExportsForLedgerResponseTypeDef",
+    {
+        "JournalS3Exports": List["JournalS3ExportDescriptionTypeDef"],
+        "NextToken": str,
+    },
+    total=False,
+)
+
+ListJournalS3ExportsResponseTypeDef = TypedDict(
+    "ListJournalS3ExportsResponseTypeDef",
+    {
+        "JournalS3Exports": List["JournalS3ExportDescriptionTypeDef"],
+        "NextToken": str,
+    },
+    total=False,
+)
+
+ListLedgersResponseTypeDef = TypedDict(
+    "ListLedgersResponseTypeDef",
+    {
+        "Ledgers": List["LedgerSummaryTypeDef"],
+        "NextToken": str,
+    },
+    total=False,
+)
+
+ListTagsForResourceResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseTypeDef",
+    {
+        "Tags": Dict[str, str],
+    },
     total=False,
 )
 
 _RequiredS3EncryptionConfigurationTypeDef = TypedDict(
-    "_RequiredS3EncryptionConfigurationTypeDef", {"ObjectEncryptionType": S3ObjectEncryptionType}
+    "_RequiredS3EncryptionConfigurationTypeDef",
+    {
+        "ObjectEncryptionType": S3ObjectEncryptionType,
+    },
 )
 _OptionalS3EncryptionConfigurationTypeDef = TypedDict(
-    "_OptionalS3EncryptionConfigurationTypeDef", {"KmsKeyArn": str}, total=False
+    "_OptionalS3EncryptionConfigurationTypeDef",
+    {
+        "KmsKeyArn": str,
+    },
+    total=False,
 )
 
 
@@ -133,113 +293,19 @@ class S3EncryptionConfigurationTypeDef(
 
 S3ExportConfigurationTypeDef = TypedDict(
     "S3ExportConfigurationTypeDef",
-    {"Bucket": str, "Prefix": str, "EncryptionConfiguration": "S3EncryptionConfigurationTypeDef"},
-)
-
-ValueHolderTypeDef = TypedDict("ValueHolderTypeDef", {"IonText": str}, total=False)
-
-CancelJournalKinesisStreamResponseTypeDef = TypedDict(
-    "CancelJournalKinesisStreamResponseTypeDef", {"StreamId": str}, total=False
-)
-
-CreateLedgerResponseTypeDef = TypedDict(
-    "CreateLedgerResponseTypeDef",
     {
-        "Name": str,
-        "Arn": str,
-        "State": LedgerState,
-        "CreationDateTime": datetime,
-        "DeletionProtection": bool,
+        "Bucket": str,
+        "Prefix": str,
+        "EncryptionConfiguration": "S3EncryptionConfigurationTypeDef",
     },
-    total=False,
-)
-
-DescribeJournalKinesisStreamResponseTypeDef = TypedDict(
-    "DescribeJournalKinesisStreamResponseTypeDef",
-    {"Stream": "JournalKinesisStreamDescriptionTypeDef"},
-    total=False,
-)
-
-DescribeJournalS3ExportResponseTypeDef = TypedDict(
-    "DescribeJournalS3ExportResponseTypeDef",
-    {"ExportDescription": "JournalS3ExportDescriptionTypeDef"},
-)
-
-DescribeLedgerResponseTypeDef = TypedDict(
-    "DescribeLedgerResponseTypeDef",
-    {
-        "Name": str,
-        "Arn": str,
-        "State": LedgerState,
-        "CreationDateTime": datetime,
-        "DeletionProtection": bool,
-    },
-    total=False,
-)
-
-ExportJournalToS3ResponseTypeDef = TypedDict("ExportJournalToS3ResponseTypeDef", {"ExportId": str})
-
-_RequiredGetBlockResponseTypeDef = TypedDict(
-    "_RequiredGetBlockResponseTypeDef", {"Block": "ValueHolderTypeDef"}
-)
-_OptionalGetBlockResponseTypeDef = TypedDict(
-    "_OptionalGetBlockResponseTypeDef", {"Proof": "ValueHolderTypeDef"}, total=False
-)
-
-
-class GetBlockResponseTypeDef(_RequiredGetBlockResponseTypeDef, _OptionalGetBlockResponseTypeDef):
-    pass
-
-
-GetDigestResponseTypeDef = TypedDict(
-    "GetDigestResponseTypeDef",
-    {"Digest": Union[bytes, IO[bytes]], "DigestTipAddress": "ValueHolderTypeDef"},
-)
-
-_RequiredGetRevisionResponseTypeDef = TypedDict(
-    "_RequiredGetRevisionResponseTypeDef", {"Revision": "ValueHolderTypeDef"}
-)
-_OptionalGetRevisionResponseTypeDef = TypedDict(
-    "_OptionalGetRevisionResponseTypeDef", {"Proof": "ValueHolderTypeDef"}, total=False
-)
-
-
-class GetRevisionResponseTypeDef(
-    _RequiredGetRevisionResponseTypeDef, _OptionalGetRevisionResponseTypeDef
-):
-    pass
-
-
-ListJournalKinesisStreamsForLedgerResponseTypeDef = TypedDict(
-    "ListJournalKinesisStreamsForLedgerResponseTypeDef",
-    {"Streams": List["JournalKinesisStreamDescriptionTypeDef"], "NextToken": str},
-    total=False,
-)
-
-ListJournalS3ExportsForLedgerResponseTypeDef = TypedDict(
-    "ListJournalS3ExportsForLedgerResponseTypeDef",
-    {"JournalS3Exports": List["JournalS3ExportDescriptionTypeDef"], "NextToken": str},
-    total=False,
-)
-
-ListJournalS3ExportsResponseTypeDef = TypedDict(
-    "ListJournalS3ExportsResponseTypeDef",
-    {"JournalS3Exports": List["JournalS3ExportDescriptionTypeDef"], "NextToken": str},
-    total=False,
-)
-
-ListLedgersResponseTypeDef = TypedDict(
-    "ListLedgersResponseTypeDef",
-    {"Ledgers": List["LedgerSummaryTypeDef"], "NextToken": str},
-    total=False,
-)
-
-ListTagsForResourceResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseTypeDef", {"Tags": Dict[str, str]}, total=False
 )
 
 StreamJournalToKinesisResponseTypeDef = TypedDict(
-    "StreamJournalToKinesisResponseTypeDef", {"StreamId": str}, total=False
+    "StreamJournalToKinesisResponseTypeDef",
+    {
+        "StreamId": str,
+    },
+    total=False,
 )
 
 UpdateLedgerResponseTypeDef = TypedDict(
@@ -253,3 +319,11 @@ UpdateLedgerResponseTypeDef = TypedDict(
     },
     total=False,
 )
+
+ValueHolderTypeDef = TypedDict(
+    "ValueHolderTypeDef",
+    {
+        "IonText": str,
+    },
+    total=False,
+)
